@@ -1,37 +1,32 @@
 import inspect
 import types
-from typing import Callable, Tuple, TypeVar
+from typing import Callable, Tuple, Type, TypeVar
 
 from .func import asyncify_func
 
 
-__all__ = (
-    'asyncify_class',
-    'ignore'
-)
+__all__ = ('asyncify_class', 'ignore')
 
 
+T = TypeVar('T')
 CallableT = TypeVar('CallableT', bound=Callable)
-TypeT = TypeVar('TypeT', bound=type)
 
 
-function_types: Tuple[type, ...] = (
-    types.FunctionType,
-    classmethod,
-    staticmethod
-)
+_FUNCTION_TYPES: Tuple[type, ...] = (types.FunctionType, classmethod, staticmethod)
 
 
 def ignore(func: CallableT) -> CallableT:
-    """
-    A decorator to ignore a function in a class when using :func:`asyncify.asyncify_class`.
+    """|deco|
+
+    Ignore a function in a class when using :func:`asyncify.asyncify_class`.
     """
     func._asyncify_ignore = True  # type: ignore
     return func
 
 
-def asyncify_class(cls: TypeT) -> TypeT:
-    """
+def asyncify_class(cls: Type[T]) -> Type[T]:
+    """|deco|
+
     Turn a classes methods into async functions.
     This uses :func:`asyncify.asyncify_func`.
     This ignores methods marked with :func:`asyncify.ignore` and `dunder` methods.
@@ -59,13 +54,11 @@ def asyncify_class(cls: TypeT) -> TypeT:
         async def main():
             await client.request('GET', 'https://python.org')
     """
+    if not inspect.isclass(cls):
+        raise TypeError('Expected class, not {!r}'.format(cls))
 
     for name, func in inspect.getmembers(cls):
-        if not isinstance(
-                func, function_types
-        ) or getattr(
-            func, '_asyncify_ignore', False
-        ) or name.startswith('__'):
+        if not isinstance(func, _FUNCTION_TYPES) or getattr(func, '_asyncify_ignore', False) or name.startswith('__'):
             continue
 
         func = asyncify_func(func)
