@@ -1,16 +1,14 @@
 import asyncio
+import inspect
 import functools
 
-from typing import TYPE_CHECKING, Any, Callable, Coroutine, TypeVar
+from typing import TYPE_CHECKING, Any, Callable, cast, Coroutine, TypeVar
 
 if TYPE_CHECKING:
     from typing_extensions import ParamSpec
-    
 
-__all__ = (
-    'asyncify_func',
-    'syncify_func'
-)
+
+__all__ = ('asyncify_func', 'syncify_func')
 
 
 T = TypeVar('T')
@@ -22,7 +20,8 @@ else:
 
 
 def asyncify_func(func: "Callable[P, T]") -> "Callable[P, Coroutine[Any, Any, T]]":
-    """
+    """|deco|
+
     Make a synchronous function into an asynchronous function by running it in a separate thread.
 
     Example
@@ -43,18 +42,23 @@ def asyncify_func(func: "Callable[P, T]") -> "Callable[P, Coroutine[Any, Any, T]
             text = await get('https://python.org')
 
         # this is very useful to turn a blocking library into an async library
-        get = asyncify(requests.get)
-    
+        get = asyncify.asyncify_func(requests.get)
+
     .. note::
-    
+
         This function uses the default loop executor.
         Change it with `loop.set_default_executor <https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.set_default_executor>`_.
     """
+    if inspect.iscoroutinefunction(func):
+        return cast("Callable[P, Coroutine[Any, Any, T]]", func)
+
+    if not callable(func):
+        raise TypeError('Expected a callable function, not {!r}'.format(func))
 
     @functools.wraps(func)
     async def async_func(*args: "P.args", **kwargs: "P.kwargs") -> T:
         new_func = functools.partial(func, *args, **kwargs)
-        
+
         loop = asyncio.get_running_loop()
         return await loop.run_in_executor(None, new_func)
 
@@ -62,7 +66,8 @@ def asyncify_func(func: "Callable[P, T]") -> "Callable[P, Coroutine[Any, Any, T]
 
 
 def syncify_func(func: "Callable[P, Coroutine[Any, Any, T]]") -> "Callable[P, T]":
-    """
+    """|deco|
+
     Make an asynchronous function a synchronous function.
 
     Example
@@ -88,14 +93,19 @@ def syncify_func(func: "Callable[P, Coroutine[Any, Any, T]]") -> "Callable[P, T]
 
             loop = asyncio.get_event_loop()
             loop.run_until_complete(coroutine_func())
-        """
+
+    .. note::
+        There must be a running event loop.
+    """
+    if inspect.isfunction(func) and not inspect.iscoroutinefunction(func):
+        return func
+
+    if not callable(func):
+        raise TypeError('Expected a callable function, not {!r}'.format(func))
 
     @functools.wraps(func)
     def sync_func(*args: "P.args", **kwargs: "P.kwargs") -> T:
-        try:
-            loop = asyncio.get_running_loop()
-        except RuntimeError:
-            loop = asyncio.new_event_loop()
+        loop = asyncio.get_running_loop()
         return loop.run_until_complete(func(*args, **kwargs))
 
     return sync_func
