@@ -1,21 +1,7 @@
-from typing import (
-    Any,
-    Callable,
-    Coroutine,
-    Generator,
-    Generic,
-    Iterable,
-    Iterator,
-    List,
-    TypeVar,
-    Optional
-)
+from typing import Any, Awaitable, Callable, Generator, Generic, Iterable, Iterator, List, TypeVar, Optional
 
 
-__all__ = (
-    'AsyncIterable',
-    'async_iter'
-)
+__all__ = ('AsyncIterable', 'async_iter')
 
 
 T = TypeVar('T')
@@ -23,11 +9,11 @@ T = TypeVar('T')
 
 class AsyncIterable(Generic[T]):
     def __init__(
-            self,
-            iterable: Iterable[T],
-            *,
-            before: Optional[Callable[[], Any]] = None,
-            after: Optional[Callable[[], Any]] = None
+        self,
+        iterable: Iterable[T],
+        *,
+        before: Optional[Callable[[], Awaitable]] = None,
+        after: Optional[Callable[[], Awaitable]] = None
     ):
         self.iterable = iterable
         self.iterator: Optional[Iterator[T]] = None
@@ -49,7 +35,7 @@ class AsyncIterable(Generic[T]):
             await self.before()
 
         try:
-            item: T = next(self.iterator)
+            item = next(self.iterator)
         except StopIteration:
             self.iterator = None
             raise StopAsyncIteration
@@ -64,9 +50,9 @@ class AsyncIterable(Generic[T]):
 
 
 def async_iter(
-        iterable: Iterable[T],
-        before: Optional[Callable[[], Any]] = None,
-        after: Optional[Callable[[], Any]] = None
+    iterable: Iterable[T],
+    before: Optional[Callable[[], Awaitable]] = None,
+    after: Optional[Callable[[], Awaitable]] = None,
 ) -> AsyncIterable[T]:
     """
     Asynchronously iterate through an iterable while calling a callback in before and/or each iteration.
@@ -75,10 +61,10 @@ def async_iter(
     ------------
     iterable: :class:`Iterable`
         The iterable to iterator over.
-    before: Optional[``Callable[[], Any]``]
-        The optional callable for before the iteration.
-    after: Optional[``Callable[[], Any]``]
-        The optional callable for after the iteration.
+    before: Optional[``Callable[<no_parameters>, Awaitable]``]
+        The optional asynchronous callable for before the iteration.
+    after: Optional[``Callable[<no_parameters>, Awaitable]``]
+        The optional asynchronous callable for after the iteration.
 
 
     .. note::
@@ -96,11 +82,9 @@ def async_iter(
             sleep = functools.partial(asyncio.sleep, 1)
 
             async for number in async_iter([1, 2, 3], sleep, before=True):
-                print("%d seconds have passed." % number)
+                print('%d seconds have passed.' % number)
     """
-    return AsyncIterable(
-        iterable,
-        before=before,
-        after=after
-    )
+    if not hasattr(iterable, '__iter__'):
+        raise TypeError('Expected object with __iter__, not {!r}'.format(iterable))
 
+    return AsyncIterable(iterable, before=before, after=after)
